#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['django_environs', 'django_environs.management']

package_data = \
{'': ['*'], 'django_environs.management': ['commands/*']}

install_requires = \
['django', 'environs[django]', 'redbaron']

extras_require = \
{'dev': ['black', 'isort'], 'test': ['tox']}

entry_points = \
{'console_scripts': ['django-environs = '
                     'django_environs.management:execute_from_command_line']}

setup(name='django-environs',
      version='0.1.1',
      description='A cli tool for bootstraping django projects with environs settings',
      author='Jarosław Wygoda',
      author_email='jaroslaw@wygoda.me',
      url='https://github.com/jwygoda/django-environs',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.6',
     )
